@@ -2,4 +2,4 @@ mod async_read_utility;
 mod async_write_utility;
 
 pub use async_read_utility::read_exact_to_vec;
-pub use async_write_utility::{AsyncWriteUtility, WriteVectorizedAll};
+pub use async_write_utility::write_vectored_all;
